"use strict";
/**
 * Utility function for constructing a multipart form in Node.js.
 *
 * @packageDocumentation
 * @internal
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.toForm = void 0;
const stream_1 = require("stream");
// eslint-disable-next-line @typescript-eslint/no-var-requires
const Multipart = require("multi-part");
/**
 * @internal
 */
async function toForm(fields) {
    const form = new Multipart();
    for (const key of Object.keys(fields)) {
        let value = fields[key];
        if (value === undefined)
            continue;
        if (!(value instanceof stream_1.Readable) &&
            !(value instanceof global.Buffer) &&
            (typeof value === "object" || typeof value === "function")) {
            value = JSON.stringify(value);
        }
        form.append(key, value);
    }
    const body = await form.buffer();
    const headers = form.getHeaders();
    delete headers["transfer-encoding"];
    return { body, headers };
}
exports.toForm = toForm;
//# sourceMappingURL=multipart.js.map